.. almir documentation master file, created by
   sphinx-quickstart on Fri Mar  9 20:27:26 2012.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to almir's documentation!
=================================

:Author: Domen Kožar <domen@dev.si>
:Source code: `github.com project <https://github.com/iElectric/almir>`_
:Bug tracker: `github.com issues <https://github.com/iElectric/almir/issues>`_
:Generated: |today|
:License: GPL v3
:Version: |release|


.. sidebar:: Features

    - supports bacula-director version 5.x.x
    - supports sqlite, postgresql, mysql databases
    - complete read-only interface for bacula-director
    - interactive web console frontend to bconsole
    - export data to excel, pdf and clipboard 
    - supports python2.6 and python 2.7
    - 100% test coverage


.. topic:: Overview

    .. include:: about.rst


.. toctree::
   :maxdepth: 4

   userguide.rst
   developer.rst
   changelog.rst
   api.rst


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

